summaryrefslogtreecommitdiff
path: root/svtools/source/inc
diff options
context:
space:
mode:
authorFrank Schoenheit [fs] <frank.schoenheit@oracle.com>2011-02-14 23:00:48 +0100
committerFrank Schoenheit [fs] <frank.schoenheit@oracle.com>2011-02-14 23:00:48 +0100
commit2b7675c9b0b3fe6accea195d6f009706c0d114ad (patch)
treed8004c2ba451a30a234d19c6978530d923d37e88 /svtools/source/inc
parentac2741f0361ea516ffe8ead57a6e43665ec99937 (diff)
parentce5f1dd187c3a7d8113c7653fa887b98fd50aaf6 (diff)
gridsort: pulled and merged DEV300_m100
Diffstat (limited to 'svtools/source/inc')
-rw-r--r--svtools/source/inc/gifread.hxx66
-rw-r--r--svtools/source/inc/jpeg.hxx10
-rw-r--r--svtools/source/inc/msgrd.hxx6
-rw-r--r--svtools/source/inc/msgwr.hxx6
-rw-r--r--svtools/source/inc/property.hxx108
-rw-r--r--svtools/source/inc/sgfbram.hxx100
-rw-r--r--svtools/source/inc/sgffilt.hxx8
-rw-r--r--svtools/source/inc/sgvmain.hxx226
-rw-r--r--svtools/source/inc/sgvspln.hxx10
-rw-r--r--svtools/source/inc/svimpbox.hxx122
-rw-r--r--svtools/source/inc/svimpicn.hxx64
-rw-r--r--svtools/source/inc/xbmread.hxx6
-rw-r--r--svtools/source/inc/xpmread.hxx60
13 files changed, 396 insertions, 396 deletions
diff --git a/svtools/source/inc/gifread.hxx b/svtools/source/inc/gifread.hxx
index de4c6935ef67..89e6c8e0df4b 100644
--- a/svtools/source/inc/gifread.hxx
+++ b/svtools/source/inc/gifread.hxx
@@ -88,41 +88,41 @@ class GIFReader : public GraphicReader
long nLastPos;
sal_uInt32 nLogWidth100;
sal_uInt32 nLogHeight100;
- USHORT nTimer;
- USHORT nGlobalWidth; // maximale Bildbreite aus Header
- USHORT nGlobalHeight; // maximale Bildhoehe aus Header
- USHORT nImageWidth; // maximale Bildbreite aus Header
- USHORT nImageHeight; // maximale Bildhoehe aus Header
- USHORT nImagePosX;
- USHORT nImagePosY;
- USHORT nImageX; // maximale Bildbreite aus Header
- USHORT nImageY; // maximale Bildhoehe aus Header
- USHORT nLastImageY;
- USHORT nLastInterCount;
- USHORT nLoops;
+ sal_uInt16 nTimer;
+ sal_uInt16 nGlobalWidth; // maximale Bildbreite aus Header
+ sal_uInt16 nGlobalHeight; // maximale Bildhoehe aus Header
+ sal_uInt16 nImageWidth; // maximale Bildbreite aus Header
+ sal_uInt16 nImageHeight; // maximale Bildhoehe aus Header
+ sal_uInt16 nImagePosX;
+ sal_uInt16 nImagePosY;
+ sal_uInt16 nImageX; // maximale Bildbreite aus Header
+ sal_uInt16 nImageY; // maximale Bildhoehe aus Header
+ sal_uInt16 nLastImageY;
+ sal_uInt16 nLastInterCount;
+ sal_uInt16 nLoops;
GIFAction eActAction;
- BOOL bStatus;
- BOOL bGCTransparent; // Ob das Bild Transparent ist, wenn ja:
- BOOL bInterlaced;
- BOOL bOverreadBlock;
- BOOL bImGraphicReady;
- BOOL bGlobalPalette;
- BYTE nBackgroundColor; // Hintergrundfarbe
- BYTE nGCTransparentIndex; // Pixel von diesem Index sind durchsichtig
- BYTE nGCDisposalMethod; // 'Disposal Method' (siehe GIF-Doku)
- BYTE cTransIndex1;
- BYTE cNonTransIndex1;
-
- void ReadPaletteEntries( BitmapPalette* pPal, ULONG nCount );
+ sal_Bool bStatus;
+ sal_Bool bGCTransparent; // Ob das Bild Transparent ist, wenn ja:
+ sal_Bool bInterlaced;
+ sal_Bool bOverreadBlock;
+ sal_Bool bImGraphicReady;
+ sal_Bool bGlobalPalette;
+ sal_uInt8 nBackgroundColor; // Hintergrundfarbe
+ sal_uInt8 nGCTransparentIndex; // Pixel von diesem Index sind durchsichtig
+ sal_uInt8 nGCDisposalMethod; // 'Disposal Method' (siehe GIF-Doku)
+ sal_uInt8 cTransIndex1;
+ sal_uInt8 cNonTransIndex1;
+
+ void ReadPaletteEntries( BitmapPalette* pPal, sal_uLong nCount );
void ClearImageExtensions();
- BOOL CreateBitmaps( long nWidth, long nHeight, BitmapPalette* pPal, BOOL bWatchForBackgroundColor );
- BOOL ReadGlobalHeader();
- BOOL ReadExtension();
- BOOL ReadLocalHeader();
- ULONG ReadNextBlock();
- void FillImages( HPBYTE pBytes, ULONG nCount );
+ sal_Bool CreateBitmaps( long nWidth, long nHeight, BitmapPalette* pPal, sal_Bool bWatchForBackgroundColor );
+ sal_Bool ReadGlobalHeader();
+ sal_Bool ReadExtension();
+ sal_Bool ReadLocalHeader();
+ sal_uLong ReadNextBlock();
+ void FillImages( HPBYTE pBytes, sal_uLong nCount );
void CreateNewBitmaps();
- BOOL ProcessGIF();
+ sal_Bool ProcessGIF();
public:
@@ -139,6 +139,6 @@ public:
// - ImportGIF -
// -------------
- BOOL ImportGIF( SvStream& rStream, Graphic& rGraphic );
+ sal_Bool ImportGIF( SvStream& rStream, Graphic& rGraphic );
#endif // _GIFREAD_HXX
diff --git a/svtools/source/inc/jpeg.hxx b/svtools/source/inc/jpeg.hxx
index 9923190c5e21..0d8db406132a 100644
--- a/svtools/source/inc/jpeg.hxx
+++ b/svtools/source/inc/jpeg.hxx
@@ -93,8 +93,8 @@ class JPEGWriter
SvStream& rOStm;
Bitmap aBmp;
BitmapReadAccess* pAcc;
- BYTE* pBuffer;
- BOOL bNative;
+ sal_uInt8* pBuffer;
+ sal_Bool bNative;
sal_Bool bGreys;
sal_Int32 nQuality;
@@ -111,7 +111,7 @@ public:
bool* pExportWasGrey = NULL );
~JPEGWriter() {};
- BOOL Write( const Graphic& rGraphic );
+ sal_Bool Write( const Graphic& rGraphic );
};
#endif // _JPEGPRIVATE
@@ -120,9 +120,9 @@ public:
// - Import/ExportJPEG -
// ---------------------
-BOOL ImportJPEG( SvStream& rStream, Graphic& rGraphic, void* pCallerData, sal_Int32 nImportFlags );
+sal_Bool ImportJPEG( SvStream& rStream, Graphic& rGraphic, void* pCallerData, sal_Int32 nImportFlags );
-BOOL ExportJPEG( SvStream& rStream,
+sal_Bool ExportJPEG( SvStream& rStream,
const Graphic& rGraphic,
const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >* pFilterData,
bool* pExportWasGrey = NULL
diff --git a/svtools/source/inc/msgrd.hxx b/svtools/source/inc/msgrd.hxx
index 2d3dcccb1244..21c0460a1c0b 100644
--- a/svtools/source/inc/msgrd.hxx
+++ b/svtools/source/inc/msgrd.hxx
@@ -29,9 +29,9 @@
#define _MSGRD_HXX
-BOOL ConvertMSGToGDIMetaFile( SvStream & rMSG, GDIMetaFile & rGDIMetaFile,
- BOOL(*pCallback)(void *, USHORT), void * pCallerData,
- ULONG nMinPercent, ULONG nMaxPercent);
+sal_Bool ConvertMSGToGDIMetaFile( SvStream & rMSG, GDIMetaFile & rGDIMetaFile,
+ sal_Bool(*pCallback)(void *, sal_uInt16), void * pCallerData,
+ sal_uLong nMinPercent, sal_uLong nMaxPercent);
#endif // _MSGRD_HXX
diff --git a/svtools/source/inc/msgwr.hxx b/svtools/source/inc/msgwr.hxx
index 7e72e98c124c..d133031673e7 100644
--- a/svtools/source/inc/msgwr.hxx
+++ b/svtools/source/inc/msgwr.hxx
@@ -29,9 +29,9 @@
#define _MSGWR_HXX
-BOOL ConvertGraphicToMSG(const Graphic & rGraphic, SvStream & rTargetStream,
- BOOL(*pCallback)(void *, USHORT), void * pCallerData,
- ULONG nMinPercent, ULONG nMaxPercent);
+sal_Bool ConvertGraphicToMSG(const Graphic & rGraphic, SvStream & rTargetStream,
+ sal_Bool(*pCallback)(void *, sal_uInt16), void * pCallerData,
+ sal_uLong nMinPercent, sal_uLong nMaxPercent);
#endif // _MSGWR_HXX
diff --git a/svtools/source/inc/property.hxx b/svtools/source/inc/property.hxx
index 689da1faf140..aa9a721fa292 100644
--- a/svtools/source/inc/property.hxx
+++ b/svtools/source/inc/property.hxx
@@ -85,13 +85,13 @@ public:
virtual SvXPropertyCtrListener* GetSvXPropertyCtrListener()=0;
virtual void SetProperty(const String &rString)=0;
virtual String GetProperty()const=0;
- virtual BOOL HasList()=0;
+ virtual sal_Bool HasList()=0;
virtual void ClearList()=0;
virtual void InsertEntry( const String& rString,
- USHORT nPos = LISTBOX_APPEND )=0;
+ sal_uInt16 nPos = LISTBOX_APPEND )=0;
virtual void SetCtrSize(const Size& rSize)=0;
- virtual void SetLocked(BOOL bLocked=TRUE)=0;
+ virtual void SetLocked(sal_Bool bLocked=sal_True)=0;
virtual void SetMyName(const String &rString)=0;
virtual String GetMyName()const=0;
@@ -135,13 +135,13 @@ public:
virtual void SetProperty(const String &rString);
virtual String GetProperty()const;
- virtual BOOL HasList();
+ virtual sal_Bool HasList();
virtual void ClearList();
virtual void InsertEntry( const String& rString,
- USHORT nPos = LISTBOX_APPEND );
+ sal_uInt16 nPos = LISTBOX_APPEND );
virtual void SetCtrSize(const Size& rSize);
- virtual void SetLocked(BOOL bLocked=TRUE);
+ virtual void SetLocked(sal_Bool bLocked=sal_True);
virtual void SetMyName(const String &rString);
virtual String GetMyName()const;
@@ -178,13 +178,13 @@ public:
virtual void SetProperty(const String &rString);
virtual String GetProperty()const;
- virtual BOOL HasList();
+ virtual sal_Bool HasList();
virtual void ClearList();
virtual void InsertEntry( const String& rString,
- USHORT nPos = LISTBOX_APPEND );
+ sal_uInt16 nPos = LISTBOX_APPEND );
virtual void SetCtrSize(const Size& rSize);
- virtual void SetLocked(BOOL bLocked=TRUE);
+ virtual void SetLocked(sal_Bool bLocked=sal_True);
virtual void SetMyName(const String &rString);
virtual String GetMyName()const;
@@ -220,13 +220,13 @@ public:
virtual void SetProperty(const String &rString);
virtual String GetProperty()const;
- virtual BOOL HasList();
+ virtual sal_Bool HasList();
virtual void ClearList();
virtual void InsertEntry( const String& rString,
- USHORT nPos = LISTBOX_APPEND );
+ sal_uInt16 nPos = LISTBOX_APPEND );
virtual void SetCtrSize(const Size& rSize);
- virtual void SetLocked(BOOL bLocked=TRUE);
+ virtual void SetLocked(sal_Bool bLocked=sal_True);
virtual void SetMyName(const String &rString);
virtual String GetMyName()const;
@@ -241,14 +241,14 @@ class SvPropertyLine : public Control
{
private:
FixedText aName;
- USHORT nNameWidth;
- BOOL bNeedsRepaint;
+ sal_uInt16 nNameWidth;
+ sal_Bool bNeedsRepaint;
SvXPropertyControl* pSvXPropertyControl;
PushButton aXButton;
- BOOL bIsLocked;
- BOOL bHasXButton;
- BOOL bIsHyperlink;
+ sal_Bool bIsLocked;
+ sal_Bool bHasXButton;
+ sal_Bool bIsHyperlink;
eKindOfControl eKindOfCtr;
protected:
@@ -260,8 +260,8 @@ public:
SvPropertyLine( Window* pParent,
const ResId& rResId );
- BOOL NeedsRepaint();
- void SetNeedsRepaint(BOOL bFlag);
+ sal_Bool NeedsRepaint();
+ void SetNeedsRepaint(sal_Bool bFlag);
void SetSvXPropertyControl(SvXPropertyControl*);
SvXPropertyControl* GetSvXPropertyControl();
@@ -270,16 +270,16 @@ public:
void SetName(const String& rString );
String GetName() const;
- void SetNameWidth(USHORT);
+ void SetNameWidth(sal_uInt16);
void ShowXButton();
void HideXButton();
- BOOL IsVisibleXButton();
- void ShowAsHyperLink(BOOL nFlag=TRUE);
- BOOL IsShownAsHyperlink();
+ sal_Bool IsVisibleXButton();
+ void ShowAsHyperLink(sal_Bool nFlag=sal_True);
+ sal_Bool IsShownAsHyperlink();
- void Locked(BOOL nFlag=TRUE);
- BOOL IsLineLocked();
+ void Locked(sal_Bool nFlag=sal_True);
+ sal_Bool IsLineLocked();
void SetClickHdl(const Link&);
@@ -294,9 +294,9 @@ public:
String aValue;
SvStrings theValues; // ???
- BOOL bHasVisibleXButton;
- BOOL bIsHyperLink;
- BOOL bIsLocked;
+ sal_Bool bHasVisibleXButton;
+ sal_Bool bIsHyperLink;
+ sal_Bool bIsLocked;
void* pDataPtr;
SvXPropertyControl* pControl;
};
@@ -378,9 +378,9 @@ private:
ScrollBar aVScroll;
SvPropLineArray PLineArray;
SvPropertyDataControl* pPropDataControl;
- USHORT nRowHeight;
- BOOL bUpdate;
- USHORT nTheNameSize;
+ sal_uInt16 nRowHeight;
+ sal_Bool bUpdate;
+ sal_uInt16 nTheNameSize;
long nYOffset;
DECL_LINK( ScrollHdl,ScrollBar*);
@@ -405,7 +405,7 @@ public:
~SvListBoxForProperties();
- virtual USHORT CalcVisibleLines();
+ virtual sal_uInt16 CalcVisibleLines();
virtual void EnableUpdate();
virtual void DisableUpdate();
@@ -413,19 +413,19 @@ public:
virtual void Clear();
- virtual USHORT InsertEntry( const SvPropertyData&, USHORT nPos = LISTBOX_APPEND );
+ virtual sal_uInt16 InsertEntry( const SvPropertyData&, sal_uInt16 nPos = LISTBOX_APPEND );
- virtual void ChangeEntry( const SvPropertyData&, USHORT nPos);
+ virtual void ChangeEntry( const SvPropertyData&, sal_uInt16 nPos);
- virtual USHORT AppendEntry( const SvPropertyData&);
+ virtual sal_uInt16 AppendEntry( const SvPropertyData&);
virtual void SetPropertyValue( const String & rEntryName, const String & rValue );
- virtual void SetFirstVisibleEntry(USHORT nPos);
- virtual USHORT GetFirstVisibleEntry();
+ virtual void SetFirstVisibleEntry(sal_uInt16 nPos);
+ virtual sal_uInt16 GetFirstVisibleEntry();
- virtual void SetSelectedEntry(USHORT nPos);
- virtual USHORT GetSelectedEntry();
+ virtual void SetSelectedEntry(sal_uInt16 nPos);
+ virtual sal_uInt16 GetSelectedEntry();
};
class SvTabPageForProperties: public TabPage
@@ -450,7 +450,7 @@ class SvBasicPropertyDataControl: public SvPropertyDataControl
{
private:
- BOOL bCorrectness;
+ sal_Bool bCorrectness;
String aEntryName;
String aEntryProperty;
String aCorrectProperty;
@@ -481,7 +481,7 @@ public:
virtual void LinkClicked(const String& aName,
void* pData);
- virtual void SetIsCorrect(BOOL nFlag);
+ virtual void SetIsCorrect(sal_Bool nFlag);
//virtual String GetTheCorrectProperty()const;
virtual void SetTheCorrectProperty(const String& aName);
@@ -521,30 +521,30 @@ public:
~SvPropertyBox();
- virtual USHORT CalcVisibleLines();
+ virtual sal_uInt16 CalcVisibleLines();
virtual void EnableUpdate(); // auch IDL?
virtual void DisableUpdate(); // auch IDL?
// AB: Hier beginnt das 'offizielle' Interface, das in IDL uebernommen werden soll
virtual void SetController(SvPropertyDataControl *);
- virtual USHORT AppendPage( const String & r );
- virtual void SetPage( USHORT );
- virtual USHORT GetCurPage();
+ virtual sal_uInt16 AppendPage( const String & r );
+ virtual void SetPage( sal_uInt16 );
+ virtual sal_uInt16 GetCurPage();
virtual void ClearAll();
virtual void ClearTable();
virtual void SetPropertyValue( const String & rEntryName, const String & rValue );
- virtual USHORT InsertEntry( const SvPropertyData&, USHORT nPos = LISTBOX_APPEND );
- virtual void ChangeEntry( const SvPropertyData&, USHORT nPos);
- virtual USHORT AppendEntry( const SvPropertyData&);
+ virtual sal_uInt16 InsertEntry( const SvPropertyData&, sal_uInt16 nPos = LISTBOX_APPEND );
+ virtual void ChangeEntry( const SvPropertyData&, sal_uInt16 nPos);
+ virtual sal_uInt16 AppendEntry( const SvPropertyData&);
- virtual void SetFirstVisibleEntry(USHORT nPos);
- virtual USHORT GetFirstVisibleEntry();
+ virtual void SetFirstVisibleEntry(sal_uInt16 nPos);
+ virtual sal_uInt16 GetFirstVisibleEntry();
- virtual void SetSelectedEntry(USHORT nPos);
- virtual USHORT GetSelectedEntry();
+ virtual void SetSelectedEntry(sal_uInt16 nPos);
+ virtual sal_uInt16 GetSelectedEntry();
};
@@ -556,8 +556,8 @@ private:
SvBasicPropertyDataControl aBaProDatCtr;
OKButton anOk;
CancelButton aCancel;
- USHORT nCount;
- USHORT nClickCount;
+ sal_uInt16 nCount;
+ sal_uInt16 nClickCount;
SvPropertyData aProperty;
SvPropertyBox aPropListBox;
diff --git a/svtools/source/inc/sgfbram.hxx b/svtools/source/inc/sgfbram.hxx
index 2acab5445a8c..aa4ed5836606 100644
--- a/svtools/source/inc/sgfbram.hxx
+++ b/svtools/source/inc/sgfbram.hxx
@@ -40,11 +40,11 @@
#define SgfDontKnow 255 /* Unbekannt oder kein SGF/SGV */
// Konstanten fr SgfHeader.SwGrCol
-#define SgfBlckWhit 1 /* Schwarz/Wei Bild Ŀ SimpVector, */
-#define SgfGrayscal 2 /* Bild mit Graustufen StarDraw und */
+#define SgfBlckWhit 1 /* Schwarz/Wei?Bild Ŀ SimpVector, */
+#define SgfGrayscal 2 /* Bild mit Graustufen ?StarDraw und */
#define Sgf16Colors 3 /* Farbbild (16 Farben) Bit Image */
#define SgfVectFarb 4 /* Farben fr Linien verwenden Ŀ */
-#define SgfVectGray 5 /* Graustufen fr Linien verwenden Nur fr */
+#define SgfVectGray 5 /* Graustufen fr Linien verwenden ?Nur fr */
#define SgfVectWdth 6 /* Strichstrken fr Linien verwenden SimpVector */
@@ -52,35 +52,35 @@
class SgfHeader
{
public:
- UINT16 Magic;
- UINT16 Version;
- UINT16 Typ;
- UINT16 Xsize;
- UINT16 Ysize;
- INT16 Xoffs;
- INT16 Yoffs;
- UINT16 Planes; // Layer
- UINT16 SwGrCol;
+ sal_uInt16 Magic;
+ sal_uInt16 Version;
+ sal_uInt16 Typ;
+ sal_uInt16 Xsize;
+ sal_uInt16 Ysize;
+ sal_Int16 Xoffs;
+ sal_Int16 Yoffs;
+ sal_uInt16 Planes; // Layer
+ sal_uInt16 SwGrCol;
char Autor[10];
char Programm[10];
- UINT16 OfsLo,OfsHi; // DWord-Allignment ist notwendig (38 mod 4 =2) !
+ sal_uInt16 OfsLo,OfsHi; // DWord-Allignment ist notwendig (38 mod 4 =2) !
- UINT32 GetOffset();
+ sal_uInt32 GetOffset();
friend SvStream& operator>>(SvStream& rIStream, SgfHeader& rHead);
- BOOL ChkMagic();
+ sal_Bool ChkMagic();
};
#define SgfEntrySize 22
class SgfEntry
{
public:
- UINT16 Typ;
- UINT16 iFrei;
- UINT16 lFreiLo,lFreiHi;
+ sal_uInt16 Typ;
+ sal_uInt16 iFrei;
+ sal_uInt16 lFreiLo,lFreiHi;
char cFrei[10];
- UINT16 OfsLo,OfsHi; // DWord-Allignment ist notwendig (18 mod 4 =2) !
+ sal_uInt16 OfsLo,OfsHi; // DWord-Allignment ist notwendig (18 mod 4 =2) !
- UINT32 GetOffset();
+ sal_uInt32 GetOffset();
friend SvStream& operator>>(SvStream& rIStream, SgfEntry& rEntr);
};
@@ -88,10 +88,10 @@ public:
class SgfVector
{
public:
- UINT16 Flag;
- INT16 x;
- INT16 y;
- UINT16 OfsLo,OfsHi; // DWord-Allignment ist notwendig (6 mod 4 =2) !
+ sal_uInt16 Flag;
+ sal_Int16 x;
+ sal_Int16 y;
+ sal_uInt16 OfsLo,OfsHi; // DWord-Allignment ist notwendig (6 mod 4 =2) !
friend SvStream& operator>>(SvStream& rIStream, SgfVector& rEntr);
};
@@ -102,7 +102,7 @@ extern long SgfVectXmul;
extern long SgfVectYmul;
extern long SgfVectXdiv;
extern long SgfVectYdiv;
-extern BOOL SgfVectScal;
+extern sal_Bool SgfVectScal;
////////////////////////////////////////////////////////////////////////////////////////////////////
// Windows BMP /////////////////////////////////////////////////////////////////////////////////////
@@ -112,15 +112,15 @@ extern BOOL SgfVectScal;
class BmpFileHeader
{
public:
- UINT16 Typ; // = "BM"
- UINT16 SizeLo,SizeHi; // Filesize in Bytes
- UINT16 Reserve1; // Reserviert
- UINT16 Reserve2; // Reserviert
- UINT16 OfsLo,OfsHi; // Offset?
-
- void SetSize(UINT32 Size);
- void SetOfs(UINT32 Size);
- UINT32 GetOfs();
+ sal_uInt16 Typ; // = "BM"
+ sal_uInt16 SizeLo,SizeHi; // Filesize in Bytes
+ sal_uInt16 Reserve1; // Reserviert
+ sal_uInt16 Reserve2; // Reserviert
+ sal_uInt16 OfsLo,OfsHi; // Offset?
+
+ void SetSize(sal_uInt32 Size);
+ void SetOfs(sal_uInt32 Size);
+ sal_uInt32 GetOfs();
friend SvStream& operator<<(SvStream& rOStream, BmpFileHeader& rHead);
};
@@ -128,17 +128,17 @@ public:
class BmpInfoHeader
{
public:
- UINT32 Size; // Gre des BmpInfoHeaders
- INT32 Width; // Breite in Pixel
- INT32 Hight; // Hhe in Pixel
- UINT16 Planes; // Anzahl der Planes (immer 1)
- UINT16 PixBits; // Anzahl der Bit je Pixel (1,4,8,oder 24)
- UINT32 Compress; // Datenkompression
- UINT32 ImgSize; // Gre der Images in Bytes. Ohne Kompression ist auch 0 erlaubt.
- INT32 xDpmm; // Dot per Meter (0 ist erlaubt)
- INT32 yDpmm; // Dot per Meter (0 ist erlaubt)
- UINT32 ColUsed; // Anzahl der verwendeten Farben (0=alle)
- UINT32 ColMust; // Anzahl der wichtigen Farben (0=alle)
+ sal_uInt32 Size; // Gre des BmpInfoHeaders
+ sal_Int32 Width; // Breite in Pixel
+ sal_Int32 Hight; // Hhe in Pixel
+ sal_uInt16 Planes; // Anzahl der Planes (immer 1)
+ sal_uInt16 PixBits; // Anzahl der Bit je Pixel (1,4,8,oder 24)
+ sal_uInt32 Compress; // Datenkompression
+ sal_uInt32 ImgSize; // Gre der Images in Bytes. Ohne Kompression ist auch 0 erlaubt.
+ sal_Int32 xDpmm; // Dot per Meter (0 ist erlaubt)
+ sal_Int32 yDpmm; // Dot per Meter (0 ist erlaubt)
+ sal_uInt32 ColUsed; // Anzahl der verwendeten Farben (0=alle)
+ sal_uInt32 ColMust; // Anzahl der wichtigen Farben (0=alle)
friend SvStream& operator<<(SvStream& rOStream, BmpInfoHeader& rHead);
};
@@ -146,12 +146,12 @@ public:
#define RGBQuadSize 4
class RGBQuad {
private:
- BYTE Red;
- BYTE Grn;
- BYTE Blu;
- BYTE Fil;
+ sal_uInt8 Red;
+ sal_uInt8 Grn;
+ sal_uInt8 Blu;
+ sal_uInt8 Fil;
public:
- RGBQuad(BYTE R, BYTE G, BYTE B) { Red=R; Grn=G; Blu=B; Fil=0; }
+ RGBQuad(sal_uInt8 R, sal_uInt8 G, sal_uInt8 B) { Red=R; Grn=G; Blu=B; Fil=0; }
};
#endif //_SGFBRAM_HXX
diff --git a/svtools/source/inc/sgffilt.hxx b/svtools/source/inc/sgffilt.hxx
index 1c75917b8f73..28d48fe13820 100644
--- a/svtools/source/inc/sgffilt.hxx
+++ b/svtools/source/inc/sgffilt.hxx
@@ -29,10 +29,10 @@
#define _SGFFILT_HXX
#include <tools/urlobj.hxx>
-BYTE CheckSgfTyp(SvStream& rInp, USHORT& nVersion);
-BOOL SgfBMapFilter(SvStream& rInp, SvStream& rOut);
-BOOL SgfVectFilter(SvStream& rInp, GDIMetaFile& rMtf);
-BOOL SgfSDrwFilter(SvStream& rInp, GDIMetaFile& rMtf, INetURLObject aIniPath );
+sal_uInt8 CheckSgfTyp(SvStream& rInp, sal_uInt16& nVersion);
+sal_Bool SgfBMapFilter(SvStream& rInp, SvStream& rOut);
+sal_Bool SgfVectFilter(SvStream& rInp, GDIMetaFile& rMtf);
+sal_Bool SgfSDrwFilter(SvStream& rInp, GDIMetaFile& rMtf, INetURLObject aIniPath );
// Konstanten fr CheckSgfTyp()
#define SGF_BITIMAGE 1 /* Bitmap */
diff --git a/svtools/source/inc/sgvmain.hxx b/svtools/source/inc/sgvmain.hxx
index 6f69908865c5..3006a23f5f10 100644
--- a/svtools/source/inc/sgvmain.hxx
+++ b/svtools/source/inc/sgvmain.hxx
@@ -36,8 +36,8 @@
#define UCHAR unsigned char
struct PointType {
- INT16 x;
- INT16 y;
+ sal_Int16 x;
+ sal_Int16 y;
};
#define SgfDpmm 40
@@ -45,7 +45,7 @@ struct PointType {
#define DtHdSize 256
class DtHdType {
public:
- BYTE Reserved[256];
+ sal_uInt8 Reserved[256];
friend SvStream& operator>>(SvStream& rIStream, DtHdType& rDtHd);
friend void DtHdOverSeek(SvStream& rInp);
};
@@ -53,30 +53,30 @@ public:
struct Seitenformat {
PointType Size; // 0.00mm...819.175mm (Papiergr��e)
- INT16 RandL; // links Rand auf
- INT16 RandR; // rechts dem Papier
- INT16 RandO; // oben Rand auf
- INT16 RandU; // unten dem Papier
- BYTE PColor; // Future Use
- BYTE PIntens; // erst recht Future use
-// BOOL BorderClip; // Objekte am Rand abschneiden (Schummel wg. Allignment unter NT)
+ sal_Int16 RandL; // links Rand auf
+ sal_Int16 RandR; // rechts dem Papier
+ sal_Int16 RandO; // oben Rand auf
+ sal_Int16 RandU; // unten dem Papier
+ sal_uInt8 PColor; // Future Use
+ sal_uInt8 PIntens; // erst recht Future use
+// sal_Bool BorderClip; // Objekte am Rand abschneiden (Schummel wg. Allignment unter NT)
};
#define PageSize 146
class PageType {
public:
- UINT32 Next; // N�chste Seite
- UINT32 nList; // Objektdaten, erster Record
- UINT32 ListEnd; // Objektdaten, letzter Record
+ sal_uInt32 Next; // N�chste Seite
+ sal_uInt32 nList; // Objektdaten, erster Record
+ sal_uInt32 ListEnd; // Objektdaten, letzter Record
Seitenformat Paper; // Papierdaten
- BOOL BorderClip; // Objekte am Rand abschneiden (Schummel wg. Allignment unter NT)
- BYTE StdPg; // welche Standardseite einblenden ?
+ sal_Bool BorderClip; // Objekte am Rand abschneiden (Schummel wg. Allignment unter NT)
+ sal_uInt8 StdPg; // welche Standardseite einblenden ?
PointType U; // Nullpunkt
- INT16 HlpLnH[20]; // Hilfslinien
- INT16 HlpLnV[20];
- BYTE LnAnzH;
- BYTE LnAnzV;
+ sal_Int16 HlpLnH[20]; // Hilfslinien
+ sal_Int16 HlpLnV[20];
+ sal_uInt8 LnAnzH;
+ sal_uInt8 LnAnzV;
UCHAR PgName[32]; // Seitenname
friend SvStream& operator>>(SvStream& rIStream, PageType& rPage);
};
@@ -86,21 +86,21 @@ enum ObjArtType {ObjStrk,ObjRect,ObjPoly,ObjCirc,ObjSpln,
ObjText,ObjGrup,ObjBmap,ObjVirt,ObjTxtX,ObjMaxi};
struct ObjLineType {
- BYTE LFarbe; // [Index]
- BYTE LBFarbe; // [Index]
- BYTE LIntens; // [%]
- BYTE LMuster; // [Index] inkl. Transparenz
- INT16 LMSize; // [Koeffizient/100]
- INT16 LDicke; // Strichst�rke
+ sal_uInt8 LFarbe; // [Index]
+ sal_uInt8 LBFarbe; // [Index]
+ sal_uInt8 LIntens; // [%]
+ sal_uInt8 LMuster; // [Index] inkl. Transparenz
+ sal_Int16 LMSize; // [Koeffizient/100]
+ sal_Int16 LDicke; // Strichst�rke
};
struct ObjAreaType {
- BYTE FFarbe; // [Index]
- BYTE FBFarbe; // [Index]
- BYTE FIntens; // [%]
- BYTE FDummy1; //
- INT16 FDummy2; //
- UINT16 FMuster; // [Index] inkl. Invers, Transparenz
+ sal_uInt8 FFarbe; // [Index]
+ sal_uInt8 FBFarbe; // [Index]
+ sal_uInt8 FIntens; // [%]
+ sal_uInt8 FDummy1; //
+ sal_Int16 FDummy2; //
+ sal_uInt16 FMuster; // [Index] inkl. Invers, Transparenz
};
#define ObjTextTypeSize 64
@@ -108,24 +108,24 @@ class ObjTextType {
public:
ObjLineType L; // Text-Outline (future)
ObjAreaType F; // Text innen
- UINT16 FontLo,FontHi;// z.B. 92500 (CG Times), zweigeteilt wegen DWordAllign in TextType.
- UINT16 Grad; // 0.5..32767.5 Pt - bei 1000 Pt sollte aber schlu� sein
- UINT16 Breite; // 1..65535% bitte nicht mehr als 500%
- BYTE Justify; // 2 Bit Vert (Hi), 3 Bit Hor (Lo)
- BYTE Kapit; // 1..255%
- UINT16 Schnitt; // 8 Flags
- UINT16 LnFeed; // 1..32767% vom max. Schriftgrad der Zeile
- UINT16 Slant; // Kursivwinkel 0.00..89.99� default 15.00� doppelt Breit angesehen)
- BYTE ZAbst; // Zeichenabstand 0..255% (0=auf der Stelle; 100=normal; 200=Zeichen wird als
- INT8 ChrVPos; // Zeichen V-Position default 0= on Baseline, 10= 5Pt drunter (-64..63�)
+ sal_uInt16 FontLo,FontHi;// z.B. 92500 (CG Times), zweigeteilt wegen DWordAllign in TextType.
+ sal_uInt16 Grad; // 0.5..32767.5 Pt - bei 1000 Pt sollte aber schlu� sein
+ sal_uInt16 Breite; // 1..65535% bitte nicht mehr als 500%
+ sal_uInt8 Justify; // 2 Bit Vert (Hi), 3 Bit Hor (Lo)
+ sal_uInt8 Kapit; // 1..255%
+ sal_uInt16 Schnitt; // 8 Flags
+ sal_uInt16 LnFeed; // 1..32767% vom max. Schriftgrad der Zeile
+ sal_uInt16 Slant; // Kursivwinkel 0.00..89.99� default 15.00� doppelt Breit angesehen)
+ sal_uInt8 ZAbst; // Zeichenabstand 0..255% (0=auf der Stelle; 100=normal; 200=Zeichen wird als
+ sal_sChar ChrVPos; // Zeichen V-Position default 0= on Baseline, 10= 5Pt drunter (-64..63�)
ObjLineType ShdL; // Schatten-Outline (neu 2.0)
ObjAreaType ShdF; // Schatten-innen (neu 2.0)
PointType ShdVers; // Schattenversatz Max.300.00%
- BOOL ShdAbs; // True-> Schattenversatz ist absolut statt relativ zum Schriftgrad
- BOOL NoSpc; // True-> kein Zwischenraum (f�r BackArea)
+ sal_Bool ShdAbs; // True-> Schattenversatz ist absolut statt relativ zum Schriftgrad
+ sal_Bool NoSpc; // True-> kein Zwischenraum (f�r BackArea)
ObjAreaType BackF; // Hintergrundfl�che
- UINT32 GetFont();
- void SetFont(UINT32 FontID);
+ sal_uInt32 GetFont();
+ void SetFont(sal_uInt32 FontID);
};
class Obj0Type { // SuperClass f�r Apple-VMT
@@ -137,16 +137,16 @@ public:
#define ObjkSize 20 /* eigentlich 21. Wg. Allignment ist Flags jedoch verschoben worden*/
class ObjkType: public Obj0Type { // Grundkomponenten aller Stardraw-Objekte
public:
- UINT32 Last;
- UINT32 Next;
- UINT16 MemSize; // in Bytes
+ sal_uInt32 Last;
+ sal_uInt32 Next;
+ sal_uInt16 MemSize; // in Bytes
PointType ObjMin; // XY-Minimum des Objekts
PointType ObjMax; // XY-Maximum des Objekts
- BYTE Art;
- BYTE Layer;
-// BYTE Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 Art;
+ sal_uInt8 Layer;
+// sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
friend SvStream& operator>>(SvStream& rIStream, ObjkType& rObjk);
- friend BOOL ObjOverSeek(SvStream& rInp, ObjkType& rObjk);
+ friend sal_Bool ObjOverSeek(SvStream& rInp, ObjkType& rObjk);
virtual void Draw(OutputDevice& rOut);
};
@@ -154,8 +154,8 @@ public:
#define StrkSize 38
class StrkType: public ObjkType {
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
- BYTE LEnden; // Linienenden
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 LEnden; // Linienenden
ObjLineType L;
PointType Pos1; // Anfangspunkt
PointType Pos2; // Endpunkt
@@ -167,15 +167,15 @@ public:
#define RectSize 52
class RectType: public ObjkType {
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
- BYTE Reserve;
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 Reserve;
ObjLineType L;
ObjAreaType F;
PointType Pos1; // LO-Ecke = Bezugspunkt
PointType Pos2; // R-Ecke
- INT16 Radius; // Eckenradius
- UINT16 DrehWink; // 315...<45
- UINT16 Slant; // >270...<90
+ sal_Int16 Radius; // Eckenradius
+ sal_uInt16 DrehWink; // 315...<45
+ sal_uInt16 Slant; // >270...<90
friend SvStream& operator>>(SvStream& rIStream, RectType& rRect);
virtual void Draw(OutputDevice& rOut);
};
@@ -184,13 +184,13 @@ public:
#define PolySize 44
class PolyType: public ObjkType { // identisch mit Spline !
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
- BYTE LEnden; // nur f�r Polyline
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 LEnden; // nur f�r Polyline
ObjLineType L;
ObjAreaType F; // nicht f�r Polyline
- BYTE nPoints;
- BYTE Reserve;
- UINT32 SD_EckP; // Zeiger auf die Eckpunkte (StarDraw)
+ sal_uInt8 nPoints;
+ sal_uInt8 Reserve;
+ sal_uInt32 SD_EckP; // Zeiger auf die Eckpunkte (StarDraw)
PointType* EckP; // Zeiger auf die Eckpunkte (StarView (wird nicht von Disk gelesen!))
friend SvStream& operator>>(SvStream& rIStream, PolyType& rPoly);
virtual void Draw(OutputDevice& rOut);
@@ -201,13 +201,13 @@ public:
#define SplnSize 44
class SplnType: public ObjkType { // identisch mit Poly !
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
- BYTE LEnden; // nur f�r nSpline
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 LEnden; // nur f�r nSpline
ObjLineType L;
ObjAreaType F; // nicht f�r nSpline
- BYTE nPoints;
- BYTE Reserve;
- UINT32 SD_EckP; // Zeiger auf die Eckpunkte (StarDraw)
+ sal_uInt8 nPoints;
+ sal_uInt8 Reserve;
+ sal_uInt32 SD_EckP; // Zeiger auf die Eckpunkte (StarDraw)
PointType* EckP; // Zeiger auf die Eckpunkte (StarView (wird nicht von Disk gelesen!))
friend SvStream& operator>>(SvStream& rIStream, SplnType& rSpln);
virtual void Draw(OutputDevice& rOut);
@@ -218,15 +218,15 @@ public:
#define CircSize 52
class CircType: public ObjkType {
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
- BYTE LEnden; // nur Bogen (Kr & El)
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 LEnden; // nur Bogen (Kr & El)
ObjLineType L;
ObjAreaType F; // nicht f�r Bogen (Kr & El)
PointType Center; // Mittelpunkt
PointType Radius; // Radius
- UINT16 DrehWink; // nur Ellipse
- UINT16 StartWink; // � nicht f�r Vollkreis
- UINT16 RelWink; // � und Vollellipse
+ sal_uInt16 DrehWink; // nur Ellipse
+ sal_uInt16 StartWink; // � nicht f�r Vollkreis
+ sal_uInt16 RelWink; // � und Vollellipse
friend SvStream& operator>>(SvStream& rIStream, CircType& rCirc);
virtual void Draw(OutputDevice& rOut);
};
@@ -239,19 +239,19 @@ public:
#define TextSize 116
class TextType: public ObjkType {
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
- BYTE Reserve; // f�r Word Allign
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 Reserve; // f�r Word Allign
ObjTextType T; // 64 Bytes << DWord-Allign bei FontID erforderlich
PointType Pos1; // Bezugspunkt (ObenLinks)
PointType Pos2; // (untenRechts)
- INT16 TopOfs; // Von Oberkante bis Textbegin (future f�r vJustify)
- UINT16 DrehWink; // 0...<360
- UINT16 BoxSlant; // >270...<90 (nur Box)
- UINT16 BufSize; // Gr��e von Buf f�r Load, Save, Copy und so
- UINT16 BufLo,BufHi;// (UCHAR*) Zeiger auf den Textbuffer << ShortArr, weil sonst DWord-Allign erforderlich
- UINT16 ExtLo,ExtHi;// (Ptr) Text �ber mehrere Rahmen << ShortArr, weil sonst DWord-Allign erforderlich
+ sal_Int16 TopOfs; // Von Oberkante bis Textbegin (future f�r vJustify)
+ sal_uInt16 DrehWink; // 0...<360
+ sal_uInt16 BoxSlant; // >270...<90 (nur Box)
+ sal_uInt16 BufSize; // Gr��e von Buf f�r Load, Save, Copy und so
+ sal_uInt16 BufLo,BufHi;// (UCHAR*) Zeiger auf den Textbuffer << ShortArr, weil sonst DWord-Allign erforderlich
+ sal_uInt16 ExtLo,ExtHi;// (Ptr) Text �ber mehrere Rahmen << ShortArr, weil sonst DWord-Allign erforderlich
PointType FitSize; // Ursprungsgr��e f�r Fit2Size
- INT16 FitBreit; // Breite zum formatieren bei Fit2Size
+ sal_Int16 FitBreit; // Breite zum formatieren bei Fit2Size
UCHAR* Buffer; // Diese Variable wird nicht durch Lesen von Disk gef�llt, sondern explizit!
friend SvStream& operator>>(SvStream& rIStream, TextType& rText);
virtual void Draw(OutputDevice& rOut);
@@ -268,21 +268,21 @@ enum GrafStat {NoGraf,Pic,Pcx,Hpgl,Img,Msp,Tiff,Dxf,Lot,Usr,Sgf};
#define BmapSize 132
class BmapType: public ObjkType {
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
- BYTE Reserve;
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 Reserve;
ObjAreaType F; // Farbe und Muster der 1-Plane Bitmap
PointType Pos1;
PointType Pos2;
- UINT16 DrehWink; // 315...<45 (Future)
- UINT16 Slant; // >270...<90 (Future)
+ sal_uInt16 DrehWink; // 315...<45 (Future)
+ sal_uInt16 Slant; // >270...<90 (Future)
UCHAR Filename[80]; // Pfad
PointType PixSize; // Gr��e in Pixel (0 bei Vektor)
GrafStat Format; // siehe GpmDef.Pas
- BYTE nPlanes; // Anzahl der Bitplanes (0 bei Vektor)
- BOOL RawOut; // als Raw ausgeben ?
- BOOL InvOut; // invertiert ausgeben ?
- BOOL LightOut; // aufhellen? (SD20)
- BYTE GrfFlg; // (SD20) 0=nSGF 1=Pcx 2=Hpgl 4=Raw $FF=Undef(f�r Fix in DrawBmp)
+ sal_uInt8 nPlanes; // Anzahl der Bitplanes (0 bei Vektor)
+ sal_Bool RawOut; // als Raw ausgeben ?
+ sal_Bool InvOut; // invertiert ausgeben ?
+ sal_Bool LightOut; // aufhellen? (SD20)
+ sal_uInt8 GrfFlg; // (SD20) 0=nSGF 1=Pcx 2=Hpgl 4=Raw $FF=Undef(f�r Fix in DrawBmp)
INetURLObject aFltPath; // F�r GraphicFilter
friend SvStream& operator>>(SvStream& rIStream, BmapType& rBmap);
@@ -294,13 +294,13 @@ public:
#define GrupSize 48
class GrupType: public ObjkType {
public:
- BYTE Flags; // (Schummel f�r Allignment unter NT)
+ sal_uInt8 Flags; // (Schummel f�r Allignment unter NT)
UCHAR Name[13]; // Name der Gruppe
- UINT16 SbLo,SbHi; // (Ptr) Gruppenliste << ShortArr, weil sonst DWord Allign erforderlich
- UINT16 UpLo,UpHi; // (Ptr) Vaterliste << ShortArr, weil sonst DWord Allign erforderlich
- UINT16 ChartSize; // Speicherbedarf der Diagrammstruktur Struktur
- UINT32 ChartPtr; // Diagrammstruktur
- UINT32 GetSubPtr(); // hier nur zum Checken, ob Sublist evtl. leer ist.
+ sal_uInt16 SbLo,SbHi; // (Ptr) Gruppenliste << ShortArr, weil sonst DWord Allign erforderlich
+ sal_uInt16 UpLo,UpHi; // (Ptr) Vaterliste << ShortArr, weil sonst DWord Allign erforderlich
+ sal_uInt16 ChartSize; // Speicherbedarf der Diagrammstruktur Struktur
+ sal_uInt32 ChartPtr; // Diagrammstruktur
+ sal_uInt32 GetSubPtr(); // hier nur zum Checken, ob Sublist evtl. leer ist.
friend SvStream& operator>>(SvStream& rIStream, GrupType& rGrup);
// virtual void Draw(OutputDevice& rOut);
};
@@ -308,26 +308,26 @@ public:
void SetLine(ObjLineType& rLine, OutputDevice& rOut);
void SetArea(ObjAreaType& rArea, OutputDevice& rOut);
-Color Sgv2SvFarbe(BYTE nFrb1, BYTE nFrb2, BYTE nInts);
-void RotatePoint(PointType& P, INT16 cx, INT16 cy, double sn, double cs);
-void RotatePoint(Point& P, INT16 cx, INT16 cy, double sn, double cs);
-INT16 iMulDiv(INT16 a, INT16 Mul, INT16 Div);
-UINT16 MulDiv(UINT16 a, UINT16 Mul, UINT16 Div);
+Color Sgv2SvFarbe(sal_uInt8 nFrb1, sal_uInt8 nFrb2, sal_uInt8 nInts);
+void RotatePoint(PointType& P, sal_Int16 cx, sal_Int16 cy, double sn, double cs);
+void RotatePoint(Point& P, sal_Int16 cx, sal_Int16 cy, double sn, double cs);
+sal_Int16 iMulDiv(sal_Int16 a, sal_Int16 Mul, sal_Int16 Div);
+sal_uInt16 MulDiv(sal_uInt16 a, sal_uInt16 Mul, sal_uInt16 Div);
class SgfFontOne {
public:
SgfFontOne* Next; // Zeiger f�r Listenverkettung
- UINT32 IFID;
- BOOL Bold;
- BOOL Ital;
- BOOL Sans;
- BOOL Serf;
- BOOL Fixd;
+ sal_uInt32 IFID;
+ sal_Bool Bold;
+ sal_Bool Ital;
+ sal_Bool Sans;
+ sal_Bool Serf;
+ sal_Bool Fixd;
FontFamily SVFamil;
CharSet SVChSet;
String SVFName; // z.B. "Times New Roman" = 15 Chars
- USHORT SVWidth; // Durchschnittliche Zeichenbreite in %
+ sal_uInt16 SVWidth; // Durchschnittliche Zeichenbreite in %
SgfFontOne();
void ReadOne( ByteString& ID, ByteString& Dsc);
};
@@ -337,15 +337,15 @@ public:
String FNam; // vollst�ndiger Filename des Inifiles
SgfFontOne* pList; // Listenanfang
SgfFontOne* Last; // Listenende
- UINT32 LastID; // f�r schnelleren Zugriff bei Wiederholungen
+ sal_uInt32 LastID; // f�r schnelleren Zugriff bei Wiederholungen
SgfFontOne* LastLn; // f�r schnelleren Zugriff bei Wiederholungen
- BOOL Tried;
+ sal_Bool Tried;
SgfFontLst();
~SgfFontLst();
void AssignFN(const String& rFName);
void ReadList();
void RausList();
- SgfFontOne* GetFontDesc(UINT32 ID);
+ SgfFontOne* GetFontDesc(sal_uInt32 ID);
};
#endif //_SGVMAIN_HXX
diff --git a/svtools/source/inc/sgvspln.hxx b/svtools/source/inc/sgvspln.hxx
index 29df09247f22..3bb7ea85374b 100644
--- a/svtools/source/inc/sgvspln.hxx
+++ b/svtools/source/inc/sgvspln.hxx
@@ -38,7 +38,7 @@
|* Polygons werden als Sttzstellen angenommen.
|* n liefert die Anzahl der Teilpolynome.
|* Ist die Berechnung fehlerfrei verlaufen, so
-|* liefert die Funktion TRUE. Nur in diesem Fall
+|* liefert die Funktion sal_True. Nur in diesem Fall
|* ist Speicher fr die Koeffizientenarrays
|* allokiert, der dann spter vom Aufrufer mittels
|* delete freizugeben ist.
@@ -47,7 +47,7 @@
|*
*************************************************************************/
-BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
+sal_Bool CalcSpline(Polygon& rPoly, sal_Bool Periodic, sal_uInt16& n,
double*& ax, double*& ay, double*& bx, double*& by,
double*& cx, double*& cy, double*& dx, double*& dy, double*& T);
@@ -58,9 +58,9 @@ BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
|* Beschreibung Konvertiert einen parametrichen kubischen
|* Polynomspline Spline (natrlich oder periodisch)
|* in ein angenhertes Polygon.
-|* Die Funktion liefert FALSE, wenn ein Fehler bei
+|* Die Funktion liefert sal_False, wenn ein Fehler bei
|* der Koeffizientenberechnung aufgetreten ist oder
-|* das Polygon zu gro wird (>PolyMax=16380). Im 1.
+|* das Polygon zu gro?wird (>PolyMax=16380). Im 1.
|* Fall hat das Polygon 0, im 2. Fall PolyMax Punkte.
|* Um Koordinatenberlufe zu vermeiden werden diese
|* auf +/-32000 begrenzt.
@@ -68,6 +68,6 @@ BOOL CalcSpline(Polygon& rPoly, BOOL Periodic, USHORT& n,
|* Letzte Aenderung JOE 23.06.93
|*
*************************************************************************/
-BOOL Spline2Poly(Polygon& rSpln, BOOL Periodic, Polygon& rPoly);
+sal_Bool Spline2Poly(Polygon& rSpln, sal_Bool Periodic, Polygon& rPoly);
#endif //_SGVSPLN_HXX
diff --git a/svtools/source/inc/xbmread.hxx b/svtools/source/inc/xbmread.hxx
index aab52eeffa63..5d6db03f73a7 100644
--- a/svtools/source/inc/xbmread.hxx
+++ b/svtools/source/inc/xbmread.hxx
@@ -69,13 +69,13 @@ class XBMReader : public GraphicReader
long nLastPos;
long nWidth;
long nHeight;
- BOOL bStatus;
+ sal_Bool bStatus;
void InitTable();
ByteString FindTokenLine( SvStream* pInStm, const char* pTok1,
const char* pTok2 = NULL, const char* pTok3 = NULL );
long ParseDefine( const sal_Char* pDefine );
- BOOL ParseData( SvStream* pInStm, const ByteString& aLastLine, XBMFormat eFormat );
+ sal_Bool ParseData( SvStream* pInStm, const ByteString& aLastLine, XBMFormat eFormat );
public:
@@ -92,6 +92,6 @@ public:
// - ImportXBM -
// -------------
-BOOL ImportXBM( SvStream& rStream, Graphic& rGraphic );
+sal_Bool ImportXBM( SvStream& rStream, Graphic& rGraphic );
#endif // _XBMREAD_HXX
diff --git a/svtools/source/inc/xpmread.hxx b/svtools/source/inc/xpmread.hxx
index 29edd15a3b1c..aea09db7596e 100644
--- a/svtools/source/inc/xpmread.hxx
+++ b/svtools/source/inc/xpmread.hxx
@@ -83,35 +83,35 @@ private:
BitmapWriteAccess* mpMaskAcc;
long mnLastPos;
- ULONG mnWidth;
- ULONG mnHeight;
- ULONG mnColors;
- ULONG mnCpp; // characters per pix
- BOOL mbTransparent;
- BOOL mbStatus;
- ULONG mnStatus;
- ULONG mnIdentifier;
- BYTE mcThisByte;
- BYTE mcLastByte;
- ULONG mnTempAvail;
- BYTE* mpTempBuf;
- BYTE* mpTempPtr;
- BYTE* mpFastColorTable;
- BYTE* mpColMap;
- ULONG mnStringSize;
- BYTE* mpStringBuf;
- ULONG mnParaSize;
- BYTE* mpPara;
-
- BOOL ImplGetString( void );
- BOOL ImplGetColor( ULONG );
- BOOL ImplGetScanLine( ULONG );
- BOOL ImplGetColSub( BYTE* );
- BOOL ImplGetColKey( BYTE );
- void ImplGetRGBHex( BYTE*, ULONG );
- BOOL ImplGetPara( ULONG numb );
- BOOL ImplCompare( BYTE*, BYTE*, ULONG, ULONG nmode = XPMCASENONSENSITIVE );
- ULONG ImplGetULONG( ULONG nPara );
+ sal_uLong mnWidth;
+ sal_uLong mnHeight;
+ sal_uLong mnColors;
+ sal_uLong mnCpp; // characters per pix
+ sal_Bool mbTransparent;
+ sal_Bool mbStatus;
+ sal_uLong mnStatus;
+ sal_uLong mnIdentifier;
+ sal_uInt8 mcThisByte;
+ sal_uInt8 mcLastByte;
+ sal_uLong mnTempAvail;
+ sal_uInt8* mpTempBuf;
+ sal_uInt8* mpTempPtr;
+ sal_uInt8* mpFastColorTable;
+ sal_uInt8* mpColMap;
+ sal_uLong mnStringSize;
+ sal_uInt8* mpStringBuf;
+ sal_uLong mnParaSize;
+ sal_uInt8* mpPara;
+
+ sal_Bool ImplGetString( void );
+ sal_Bool ImplGetColor( sal_uLong );
+ sal_Bool ImplGetScanLine( sal_uLong );
+ sal_Bool ImplGetColSub( sal_uInt8* );
+ sal_Bool ImplGetColKey( sal_uInt8 );
+ void ImplGetRGBHex( sal_uInt8*, sal_uLong );
+ sal_Bool ImplGetPara( sal_uLong numb );
+ sal_Bool ImplCompare( sal_uInt8*, sal_uInt8*, sal_uLong, sal_uLong nmode = XPMCASENONSENSITIVE );
+ sal_uLong ImplGetULONG( sal_uLong nPara );
public:
XPMReader( SvStream& rStm );
@@ -126,6 +126,6 @@ public:
// - ImportXPM -
// -------------
-BOOL ImportXPM( SvStream& rStream, Graphic& rGraphic );
+sal_Bool ImportXPM( SvStream& rStream, Graphic& rGraphic );
#endif // _XPMREAD_HXX
diff --git a/svtools/source/inc/svimpbox.hxx b/svtools/source/inc/svimpbox.hxx
index f9e4ee6951fb..d90329afb28d 100644
--- a/svtools/source/inc/svimpbox.hxx
+++ b/svtools/source/inc/svimpbox.hxx
@@ -64,9 +64,9 @@ public:
void BeginDrag();
void CreateAnchor();
void DestroyAnchor();
- BOOL SetCursorAtPoint( const Point& rPoint,
- BOOL bDontSelectAtCursor=FALSE );
- BOOL IsSelectionAtPoint( const Point& rPoint );
+ sal_Bool SetCursorAtPoint( const Point& rPoint,
+ sal_Bool bDontSelectAtCursor=sal_False );
+ sal_Bool IsSelectionAtPoint( const Point& rPoint );
void DeselectAtPoint( const Point& rPoint );
void DeselectAll();
};
@@ -147,22 +147,22 @@ private:
long nNodeBmpWidth;
long nNextVerVisSize;
long nMostRight;
- ULONG nVisibleCount; // Anzahl Zeilen im Control
- ULONG nCurUserEvent; //-1 == kein Userevent amn Laufen
+ sal_uLong nVisibleCount; // Anzahl Zeilen im Control
+ sal_uLong nCurUserEvent; //-1 == kein Userevent amn Laufen
short nHorSBarHeight, nVerSBarWidth;
- USHORT nFlags;
- USHORT nCurTabPos;
+ sal_uInt16 nFlags;
+ sal_uInt16 nCurTabPos;
WinBits m_nStyle;
ExtendedWinBits nExtendedWinBits;
- BOOL bSimpleTravel : 1; // ist TRUE bei SINGLE_SELECTION
- BOOL bUpdateMode : 1;
- BOOL bInVScrollHdl : 1;
- BOOL bAsyncBeginDrag : 1;
- BOOL bSubLstOpRet : 1; // open/close sublist with return/enter, defaulted with FALSE
- BOOL bSubLstOpLR : 1; // open/close sublist with cursor left/right, defaulted with FALSE
- BOOL bContextMenuHandling : 1;
- BOOL bIsCellFocusEnabled : 1;
+ sal_Bool bSimpleTravel : 1; // ist sal_True bei SINGLE_SELECTION
+ sal_Bool bUpdateMode : 1;
+ sal_Bool bInVScrollHdl : 1;
+ sal_Bool bAsyncBeginDrag : 1;
+ sal_Bool bSubLstOpRet : 1; // open/close sublist with return/enter, defaulted with sal_False
+ sal_Bool bSubLstOpLR : 1; // open/close sublist with cursor left/right, defaulted with sal_False
+ sal_Bool bContextMenuHandling : 1;
+ sal_Bool bIsCellFocusEnabled : 1;
sal_Bool bAreChildrenTransient;
@@ -186,16 +186,16 @@ private:
void ShowVerSBar();
// setzt Thumb auf FirstEntryToDraw
void SyncVerThumb();
- BOOL IsLineVisible( long nY ) const;
+ sal_Bool IsLineVisible( long nY ) const;
long GetEntryLine( SvLBoxEntry* pEntry ) const;
void FillView();
void CursorDown();
void CursorUp();
void KeyLeftRight( long nDiff );
- void PageDown( USHORT nDelta );
- void PageUp( USHORT nDelta );
+ void PageDown( sal_uInt16 nDelta );
+ void PageUp( sal_uInt16 nDelta );
- void SetCursor( SvLBoxEntry* pEntry, BOOL bForceNoSelect = FALSE );
+ void SetCursor( SvLBoxEntry* pEntry, sal_Bool bForceNoSelect = sal_False );
void DrawNet();
@@ -209,39 +209,39 @@ private:
// Selection-Engine
SvLBoxEntry* MakePointVisible( const Point& rPoint,
- BOOL bNotifyScroll=TRUE );
+ sal_Bool bNotifyScroll=sal_True );
void SetAnchorSelection( SvLBoxEntry* pOld,
SvLBoxEntry* pNewCursor );
void BeginDrag();
- BOOL ButtonDownCheckCtrl( const MouseEvent& rMEvt,
+ sal_Bool ButtonDownCheckCtrl( const MouseEvent& rMEvt,
SvLBoxEntry* pEntry, long nY );
- BOOL MouseMoveCheckCtrl( const MouseEvent& rMEvt,
+ sal_Bool MouseMoveCheckCtrl( const MouseEvent& rMEvt,
SvLBoxEntry* pEntry );
- BOOL ButtonUpCheckCtrl( const MouseEvent& rMEvt );
- BOOL ButtonDownCheckExpand( const MouseEvent&,
+ sal_Bool ButtonUpCheckCtrl( const MouseEvent& rMEvt );
+ sal_Bool ButtonDownCheckExpand( const MouseEvent&,
SvLBoxEntry*,long nY );
- void PositionScrollBars( Size& rOSize, USHORT nMask );
- USHORT AdjustScrollBars( Size& rSize );
+ void PositionScrollBars( Size& rOSize, sal_uInt16 nMask );
+ sal_uInt16 AdjustScrollBars( Size& rSize );
void BeginScroll();
void EndScroll();
- BOOL InScroll() const { return (BOOL)(nFlags & F_IN_SCROLLING)!=0;}
+ sal_Bool InScroll() const { return (sal_Bool)(nFlags & F_IN_SCROLLING)!=0;}
Rectangle GetVisibleArea() const;
- BOOL EntryReallyHit(SvLBoxEntry* pEntry,const Point& rPos,long nLine);
+ sal_Bool EntryReallyHit(SvLBoxEntry* pEntry,const Point& rPos,long nLine);
void InitScrollBarBox();
SvLBoxTab* NextTab( SvLBoxTab* );
- BOOL SetMostRight( SvLBoxEntry* pEntry );
+ sal_Bool SetMostRight( SvLBoxEntry* pEntry );
void FindMostRight( SvLBoxEntry* EntryToIgnore );
void FindMostRight( SvLBoxEntry* pParent, SvLBoxEntry* EntryToIgnore );
void FindMostRight_Impl( SvLBoxEntry* pParent,SvLBoxEntry* EntryToIgnore );
void NotifyTabsChanged();
- inline BOOL IsExpandable() const // if element at cursor can be expanded in general
+ inline sal_Bool IsExpandable() const // if element at cursor can be expanded in general
{ return pCursor->HasChilds() || pCursor->HasChildsOnDemand(); }
- inline BOOL IsNowExpandable() const // if element at cursor can be expanded at this moment
+ inline sal_Bool IsNowExpandable() const // if element at cursor can be expanded at this moment
{ return IsExpandable() && !pView->IsExpanded( pCursor ); }
static void implInitDefaultNodeImages();
@@ -280,40 +280,40 @@ public:
void EntryExpanded( SvLBoxEntry* pEntry );
void EntryCollapsed( SvLBoxEntry* pEntry );
void CollapsingEntry( SvLBoxEntry* pEntry );
- void EntrySelected( SvLBoxEntry*, BOOL bSelect );
+ void EntrySelected( SvLBoxEntry*, sal_Bool bSelect );
void Paint( const Rectangle& rRect );
void RepaintSelectionItems();
void MouseButtonDown( const MouseEvent& );
void MouseButtonUp( const MouseEvent& );
void MouseMove( const MouseEvent&);
- BOOL KeyInput( const KeyEvent& );
+ sal_Bool KeyInput( const KeyEvent& );
void Resize();
void GetFocus();
void LoseFocus();
void UpdateAll(
- BOOL bInvalidateCompleteView= TRUE,
- BOOL bUpdateVerSBar = TRUE );
+ sal_Bool bInvalidateCompleteView= sal_True,
+ sal_Bool bUpdateVerSBar = sal_True );
void SetEntryHeight( short nHeight );
void PaintEntry( SvLBoxEntry* pEntry );
void InvalidateEntry( SvLBoxEntry* );
void RecalcFocusRect();
- inline void SelectEntry( SvLBoxEntry* pEntry, BOOL bSelect );
+ inline void SelectEntry( SvLBoxEntry* pEntry, sal_Bool bSelect );
void SetDragDropMode( DragDropMode eDDMode );
void SetSelectionMode( SelectionMode eSelMode );
- void SetAddMode( BOOL ) { aSelEng.AddAlways(FALSE); }
- BOOL IsAddMode() const { return aSelEng.IsAlwaysAdding(); }
+ void SetAddMode( sal_Bool ) { aSelEng.AddAlways(sal_False); }
+ sal_Bool IsAddMode() const { return aSelEng.IsAlwaysAdding(); }
SvLBoxEntry* GetCurrentEntry() const { return pCursor; }
- BOOL IsEntryInView( SvLBoxEntry* ) const;
+ sal_Bool IsEntryInView( SvLBoxEntry* ) const;
SvLBoxEntry* GetEntry( const Point& rPos ) const;
// gibt letzten Eintrag zurueck, falls Pos unter letztem Eintrag
SvLBoxEntry* GetClickedEntry( const Point& ) const;
SvLBoxEntry* GetCurEntry() const { return pCursor; }
void SetCurEntry( SvLBoxEntry* );
Point GetEntryPosition( SvLBoxEntry* ) const;
- void MakeVisible( SvLBoxEntry* pEntry, BOOL bMoveToTop=FALSE );
+ void MakeVisible( SvLBoxEntry* pEntry, sal_Bool bMoveToTop=sal_False );
void PaintDDCursor( SvLBoxEntry* );
@@ -338,38 +338,38 @@ public:
static const Image& GetDefaultCollapsedNodeImage( BmpColorMode _eMode = BMP_COLOR_NORMAL );
const Size& GetOutputSize() const { return aOutputSize;}
- void KeyUp( BOOL bPageUp, BOOL bNotifyScroll = TRUE );
- void KeyDown( BOOL bPageDown, BOOL bNotifyScroll = TRUE );
+ void KeyUp( sal_Bool bPageUp, sal_Bool bNotifyScroll = sal_True );
+ void KeyDown( sal_Bool bPageDown, sal_Bool bNotifyScroll = sal_True );
void Command( const CommandEvent& rCEvt );
void Invalidate();
void DestroyAnchor() { pAnchor=0; aSelEng.Reset(); }
- void SelAllDestrAnch( BOOL bSelect,
- BOOL bDestroyAnchor = TRUE,
- BOOL bSingleSelToo = FALSE );
- void ShowCursor( BOOL bShow );
+ void SelAllDestrAnch( sal_Bool bSelect,
+ sal_Bool bDestroyAnchor = sal_True,
+ sal_Bool bSingleSelToo = sal_False );
+ void ShowCursor( sal_Bool bShow );
- BOOL RequestHelp( const HelpEvent& rHEvt );
+ sal_Bool RequestHelp( const HelpEvent& rHEvt );
void EndSelection();
- BOOL IsNodeButton( const Point& rPosPixel, SvLBoxEntry* pEntry ) const;
+ sal_Bool IsNodeButton( const Point& rPosPixel, SvLBoxEntry* pEntry ) const;
void RepaintScrollBars();
- void EnableAsyncDrag( BOOL b) { bAsyncBeginDrag = b; }
- void SetUpdateMode( BOOL );
- void SetUpdateModeFast( BOOL );
- BOOL GetUpdateMode() const { return bUpdateMode; }
+ void EnableAsyncDrag( sal_Bool b) { bAsyncBeginDrag = b; }
+ void SetUpdateMode( sal_Bool );
+ void SetUpdateModeFast( sal_Bool );
+ sal_Bool GetUpdateMode() const { return bUpdateMode; }
Rectangle GetClipRegionRect() const;
- BOOL HasHorScrollBar() const { return aHorSBar.IsVisible(); }
+ sal_Bool HasHorScrollBar() const { return aHorSBar.IsVisible(); }
void ShowFocusRect( const SvLBoxEntry* pEntry );
void SetTabBar( TabBar* pTabBar );
void CancelPendingEdit();
- void CallEventListeners( ULONG nEvent, void* pData = NULL );
+ void CallEventListeners( sal_uLong nEvent, void* pData = NULL );
/** Enables, that one cell of a tablistbox entry can be focused */
- inline BOOL IsCellFocusEnabled() const { return bIsCellFocusEnabled; }
- inline void EnableCellFocus() { bIsCellFocusEnabled = TRUE; }
- bool SetCurrentTabPos( USHORT _nNewPos );
- inline USHORT GetCurrentTabPos() const { return nCurTabPos; }
+ inline sal_Bool IsCellFocusEnabled() const { return bIsCellFocusEnabled; }
+ inline void EnableCellFocus() { bIsCellFocusEnabled = sal_True; }
+ bool SetCurrentTabPos( sal_uInt16 _nNewPos );
+ inline sal_uInt16 GetCurrentTabPos() const { return nCurTabPos; }
bool IsSelectable( const SvLBoxEntry* pEntry );
};
@@ -457,11 +457,11 @@ inline void SvImpLBox::PaintEntry( SvLBoxEntry* pEntry )
pView->PaintEntry( pEntry, nY );
}
-inline BOOL SvImpLBox::IsLineVisible( long nY ) const
+inline sal_Bool SvImpLBox::IsLineVisible( long nY ) const
{
- BOOL bRet = TRUE;
+ sal_Bool bRet = sal_True;
if ( nY < 0 || nY >= aOutputSize.Height() )
- bRet = FALSE;
+ bRet = sal_False;
return bRet;
}
diff --git a/svtools/source/inc/svimpicn.hxx b/svtools/source/inc/svimpicn.hxx
index 7d5c2b1b41e3..b516ca9bfe25 100644
--- a/svtools/source/inc/svimpicn.hxx
+++ b/svtools/source/inc/svimpicn.hxx
@@ -103,8 +103,8 @@ class SvImpIconView
long nMaxBmpHeight;
long nMaxTextWidth;
long nMaxBoundHeight; // Hoehe des hoechsten BoundRects
- ULONG nFlags;
- ULONG nCurUserEvent;
+ sal_uLong nFlags;
+ sal_uLong nCurUserEvent;
SvLBoxEntry* pCurParent;
SvLBoxEntry* pCursor;
SvLBoxEntry* pNextCursor; // wird in MovingEntry gesetzt und ist
@@ -115,12 +115,12 @@ class SvImpIconView
VirtualDevice* pDDTempDev;
SvIconViewTextMode eTextMode;
- BOOL bMustRecalcBoundingRects;
+ sal_Bool bMustRecalcBoundingRects;
void CheckAllSizes();
void CheckSizes( SvLBoxEntry* pEntry,
const SvIcnVwDataEntry* pViewData = 0 );
- void ShowCursor( BOOL bShow );
+ void ShowCursor( sal_Bool bShow );
void SetNextEntryPos(const Point& rPos);
Point FindNextEntryPos( const Size& rBoundSize );
@@ -137,7 +137,7 @@ class SvImpIconView
void AdjustScrollBars();
void PositionScrollBars( long nRealWidth, long nRealHeight );
void CalcDocPos( Point& aMousePos );
- BOOL GetResizeRect( Rectangle& );
+ sal_Bool GetResizeRect( Rectangle& );
void PaintResizeRect( const Rectangle& );
SvLBoxEntry* GetNewCursor();
void ToggleSelection( SvLBoxEntry* );
@@ -160,8 +160,8 @@ class SvImpIconView
SvIconViewTextMode GetEntryTextModeSmart( const SvLBoxEntry* pEntry,
const SvIcnVwDataEntry* pViewData ) const;
- BOOL CheckVerScrollBar();
- BOOL CheckHorScrollBar();
+ sal_Bool CheckVerScrollBar();
+ sal_Bool CheckHorScrollBar();
void CancelUserEvent();
public:
@@ -169,7 +169,7 @@ public:
SvImpIconView( SvIconView* pView, SvLBoxTreeList*, WinBits nWinStyle );
~SvImpIconView();
- void Clear( BOOL bInCtor = FALSE );
+ void Clear( sal_Bool bInCtor = sal_False );
void SetStyle( const WinBits i_nWinStyle );
void SetModel( SvLBoxTreeList* pTree, SvLBoxEntry* pParent )
{ pModel = pTree; SetCurParent(pParent); }
@@ -184,14 +184,14 @@ public:
void EntryExpanded( SvLBoxEntry* pEntry );
void EntryCollapsed( SvLBoxEntry* pEntry );
void CollapsingEntry( SvLBoxEntry* pEntry );
- void EntrySelected( SvLBoxEntry*, BOOL bSelect );
+ void EntrySelected( SvLBoxEntry*, sal_Bool bSelect );
void Paint( const Rectangle& rRect );
void RepaintSelectionItems();
void MouseButtonDown( const MouseEvent& );
void MouseButtonUp( const MouseEvent& );
void MouseMove( const MouseEvent&);
- BOOL KeyInput( const KeyEvent& );
+ sal_Bool KeyInput( const KeyEvent& );
void Resize();
void GetFocus();
void LoseFocus();
@@ -201,8 +201,8 @@ public:
void PaintEntry( SvLBoxEntry*, const Point&,
SvIcnVwDataEntry* pViewData = 0, OutputDevice* pOut = 0);
void SetEntryPosition( SvLBoxEntry* pEntry, const Point& rPos,
- BOOL bAdjustRow = FALSE,
- BOOL bCheckScrollBars = FALSE );
+ sal_Bool bAdjustRow = sal_False,
+ sal_Bool bCheckScrollBars = sal_False );
void InvalidateEntry( SvLBoxEntry* );
void ViewDataInitialized( SvLBoxEntry* pEntry );
SvLBoxItem* GetItem( SvLBoxEntry*, const Point& rAbsPos );
@@ -217,7 +217,7 @@ public:
SvLBoxEntry* GetCurEntry() const { return pCursor; }
void SetCursor( SvLBoxEntry* );
- BOOL IsEntryInView( SvLBoxEntry* );
+ sal_Bool IsEntryInView( SvLBoxEntry* );
SvLBoxEntry* GetEntry( const Point& rDocPos );
SvLBoxEntry* GetNextEntry( const Point& rDocPos, SvLBoxEntry* pCurEntry );
SvLBoxEntry* GetPrevEntry( const Point& rDocPos, SvLBoxEntry* pCurEntry );
@@ -237,7 +237,7 @@ public:
SvIcnVwDataEntry* pViewData=0 );
Rectangle CalcTextRect( SvLBoxEntry*, SvLBoxString* pItem = 0,
const Point* pPos = 0,
- BOOL bForInplaceEdit = FALSE,
+ sal_Bool bForInplaceEdit = sal_False,
SvIcnVwDataEntry* pViewData = 0 );
long CalcBoundingWidth( SvLBoxEntry*, const SvIcnVwDataEntry* pViewData = 0) const;
@@ -254,22 +254,22 @@ public:
SvIcnVwDataEntry* pViewData=0);
void InvalidateBoundingRect( SvLBoxEntry* );
void InvalidateBoundingRect( Rectangle& rRect ) { rRect.Right() = LONG_MAX; }
- BOOL IsBoundingRectValid( const Rectangle& rRect ) const { return (BOOL)( rRect.Right() != LONG_MAX ); }
+ sal_Bool IsBoundingRectValid( const Rectangle& rRect ) const { return (sal_Bool)( rRect.Right() != LONG_MAX ); }
- void PaintEmphasis( const Rectangle&, BOOL bSelected,
- BOOL bCursored, OutputDevice* pOut = 0 );
+ void PaintEmphasis( const Rectangle&, sal_Bool bSelected,
+ sal_Bool bCursored, OutputDevice* pOut = 0 );
void PaintItem( const Rectangle& rRect, SvLBoxItem* pItem,
- SvLBoxEntry* pEntry, USHORT nPaintFlags, OutputDevice* pOut = 0 );
- // berechnet alle BoundingRects neu, wenn bMustRecalcBoundingRects == TRUE
+ SvLBoxEntry* pEntry, sal_uInt16 nPaintFlags, OutputDevice* pOut = 0 );
+ // berechnet alle BoundingRects neu, wenn bMustRecalcBoundingRects == sal_True
void CheckBoundingRects() { if (bMustRecalcBoundingRects) RecalcAllBoundingRects(); }
// berechnet alle invalidierten BoundingRects neu
void UpdateBoundingRects();
- void ShowTargetEmphasis( SvLBoxEntry* pEntry, BOOL bShow );
+ void ShowTargetEmphasis( SvLBoxEntry* pEntry, sal_Bool bShow );
SvLBoxEntry* GetDropTarget( const Point& rPosPixel );
- BOOL NotifyMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
- SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos );
- BOOL NotifyCopying( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
- SvLBoxEntry*& rpNewParent, ULONG& rNewChildPos );
+ sal_Bool NotifyMoving( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
+ SvLBoxEntry*& rpNewParent, sal_uLong& rNewChildPos );
+ sal_Bool NotifyCopying( SvLBoxEntry* pTarget, SvLBoxEntry* pEntry,
+ SvLBoxEntry*& rpNewParent, sal_uLong& rNewChildPos );
void WriteDragServerInfo( const Point&, SvLBoxDDInfo* );
void ReadDragServerInfo( const Point&, SvLBoxDDInfo* );
@@ -277,9 +277,9 @@ public:
void SetCurParent( SvLBoxEntry* pNewParent );
SvLBoxEntry* GetCurParent() const { return pCurParent; }
- USHORT GetSelectionCount() const;
+ sal_uInt16 GetSelectionCount() const;
void SetGrid( long nDX, long nDY );
- void Scroll( long nDeltaX, long nDeltaY, BOOL bScrollBar = FALSE );
+ void Scroll( long nDeltaX, long nDeltaY, sal_Bool bScrollBar = sal_False );
const Size& GetItemSize( SvIconView* pView, SvLBoxEntry*, SvLBoxItem*,
const SvIcnVwDataEntry* pViewData = 0 ) const;
void PrepareCommandEvent( const Point& rPt );
@@ -290,18 +290,18 @@ public:
SvLBoxEntry* mpViewData;
- BOOL IsOver( SvPtrarr* pSelectedRectList, const Rectangle& rEntryBoundRect ) const;
- void SelectRect( const Rectangle&, BOOL bAdd = TRUE,
+ sal_Bool IsOver( SvPtrarr* pSelectedRectList, const Rectangle& rEntryBoundRect ) const;
+ void SelectRect( const Rectangle&, sal_Bool bAdd = sal_True,
SvPtrarr* pOtherRects = 0,
short nOffs = SELRECT_BORDER_OFFS );
void DrawSelectionRect( const Rectangle& );
void HideSelectionRect();
void CalcScrollOffsets( const Point& rRefPosPixel,
- long& rX, long& rY, BOOL bDragDrop = FALSE,
- USHORT nBorderWidth = 10 );
+ long& rX, long& rY, sal_Bool bDragDrop = sal_False,
+ sal_uInt16 nBorderWidth = 10 );
void EndTracking();
- BOOL IsTextHit( SvLBoxEntry* pEntry, const Point& rDocPos );
- void MakeVisible( const Rectangle& rDocPos,BOOL bInScrollBarEvent=FALSE);
+ sal_Bool IsTextHit( SvLBoxEntry* pEntry, const Point& rDocPos );
+ void MakeVisible( const Rectangle& rDocPos,sal_Bool bInScrollBarEvent=sal_False);
void AdjustAtGrid( SvLBoxEntry* pStart = 0 );
void SetTextMode( SvIconViewTextMode, SvLBoxEntry* pEntry = 0 );
SvIconViewTextMode GetTextMode( const SvLBoxEntry* pEntry = 0,